Suweal
Suweal is a library for interacting with SurrealDB. This library is currently unpublished with no currently plans to publish it.
⚠️ This library is highly experimental and subject to change.
[dependencies]
suweal = ">= 0.3.1 and < 1.0.0"
import suweal
pub fn main() -> Nil {}