suweal/response

Types

The response type for the INFO TABLE command. The TABLE command returns information regarding the events, fields, tables, and live statement configurations on a specific table.

INFO FOR TABLE $table_name;

https://surrealdb.com/docs/reference/query-language/statements/info#table-information

pub type InfoTableResponse {
  InfoTableResponse(
    events: List(#(String, String)),
    fields: List(#(String, String)),
    indexes: List(#(String, String)),
    lives: List(#(String, String)),
    tables: List(#(String, String)),
  )
}

Constructors

  • InfoTableResponse(
      events: List(#(String, String)),
      fields: List(#(String, String)),
      indexes: List(#(String, String)),
      lives: List(#(String, String)),
      tables: List(#(String, String)),
    )

Values

pub fn info_table_response_decoder() -> decode.Decoder(
  InfoTableResponse,
)
✨ Search Document