suweal/surreal_sim
Values
pub fn connection() -> suweal.Connection
pub fn with_surreal_db(next: fn(suweal.Connection) -> a) -> a
Run a function with a surrealDB instance running in memory. The properties of the database are passed through the connection parameter.
This should only be used for testing purposes and may potentially be unsafe.